@@ -3,7 +3,7 @@ use utf8;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 use Class::Accessor::Fast qw/antlers/;
@@ -62,7 +62,7 @@ sub prepare_text_for_markdown {
     $text =~ s/^[ ]{1,3}([^ <])/　$1/mg;
 
     ## Work Around: リストの後にコードブロックが続くとだめな問題 (issue #6)
-    $text =~ s![-*+] (.*?)\n\n    !- $1\n\n　\n\n    !g;
+    $text =~ s!([-*+] .*?)\n\n    !$1\n\n　\n\n    !g;
 
     return $text;
 }
@@ -82,7 +82,9 @@ sub to_html_tree {
     my $text = shift;
 
     $text = prepare_text_for_markdown($text);
-    my $html = markdown($text);
+    my $html = markdown($text,
+        extensions => HOEDOWN_EXT_FENCED_CODE,
+    );
     $html = prepare_html_for_inao($html);
 
     my $tree = HTML::TreeBuilder->new;
